#include <X11/Xlib.h>
#include <string.h>

#include "mod.h"
#include "data.h"

unsigned int ignored_mask = LockMask | Mod2Mask;

char *mod_string[] = {
        "shift",
        "lock",
        "control",
        "mod1",
        "mod2",
        "mod3",
        "mod4",
        "mod5" 
};

unsigned int mod_mask[] = {
        ShiftMask, 
        LockMask, 
        ControlMask, 
        Mod1Mask,
        Mod2Mask,
        Mod3Mask,
        Mod4Mask,
        Mod5Mask 
};


/* <shift-mod1-slash> -> key */
int 
parse_key(char *name, struct key *key)
{
        char *s;
        char *stok = NULL;
        key->state = 0;
        key->keysym = 0;
        s = strrchr(name, '-');
        key->keysym = XStringToKeysym(s ? s + 1 : name);
        if(key->keysym == NoSymbol) {
                fprintf(stderr, "unknown keysym: '%s'\n", s ? s + 1 : name);
                return 1;
        }
        if(!s)
                return 0;
        *s = '\0';
        while (( s = strtok_r(name, "-", &stok))) {
                int i = 0;
                if(!strcmp("*",s)) {
                        key->state = AnyModifier;
                } else {
                        for(; i < 8; i++)
                                if(!strcasecmp(mod_string[i], s)) {
                                        key->state |= mod_mask[i];
                                        break;
                                }
                        if(i == 8) {
                                fprintf(stderr, "unknown modifer: '%s'\n", s );
                                return 1;
                        }
                }
                if(name) name = NULL;

        }


        return 0;
}

void
print_key(FILE *file, struct key *key) 
{
        int i;
        char *s;
        if(!key)
                fprintf(file, "(null)");
        if (key->state == AnyModifier) 
                fputs("*-", file); 
        else
                for(i = 0; i < 8; i++) {
                        if(key->state & mod_mask[i]) {
                                fprintf(file, "%s-", mod_string[i]);
                        }
                }
        s = XKeysymToString(key->keysym);
        if(s) 
                fputs(s,file);
}


